Documentation
¶
Index ¶
- Variables
- type ConditionStatus
- type Option
- type Volume
- func (v *Volume) CreateTime() string
- func (v *Volume) Driver() string
- func (v *Volume) FileSystem() []string
- func (v *Volume) Key() string
- func (v *Volume) Label(label string) string
- func (v *Volume) MountOption() []string
- func (v *Volume) Option(name string) string
- func (v *Volume) Options() map[string]string
- func (v *Volume) Path() string
- func (v *Volume) SetLabel(label, value string)
- func (v *Volume) SetOption(name, value string)
- func (v *Volume) SetPath(p string)
- func (v *Volume) Size() string
- func (v *Volume) VolumeContext() VolumeContext
- type VolumeCondition
- type VolumeConditionType
- type VolumeConfig
- type VolumeContext
- type VolumePhase
- type VolumeSpec
- type VolumeStatus
Constants ¶
This section is empty.
Variables ¶
var ( // OptionRef defines the reference of containers. OptionRef = "ref" // DefaultBackend defines the default volume backend. DefaultBackend = "local" )
Functions ¶
This section is empty.
Types ¶
type ConditionStatus ¶
type ConditionStatus string
ConditionStatus string enum.
const ( // ConditionTrue NodeConditionType is true. ConditionTrue ConditionStatus = "True" // ConditionFalse NodeConditionType is false. ConditionFalse ConditionStatus = "False" // ConditionUnknown NodeConditionType is Unknown. ConditionUnknown ConditionStatus = "Unknown" )
type Volume ¶
type Volume struct {
meta.ObjectMeta `json:",inline"`
Spec *VolumeSpec `json:"Spec,omitempty"`
Status *VolumeStatus `json:"Status,omitempty"`
}
Volume defined volume struct.
func NewVolumeFromContext ¶
func NewVolumeFromContext(mountPath, size string, id VolumeContext) *Volume
NewVolumeFromContext will create an Volume using mountPath, size and VolumeContext.
func (*Volume) CreateTime ¶
CreateTime returns the volume's create time.
func (*Volume) FileSystem ¶
FileSystem returns volume's file system.
func (*Volume) MountOption ¶
MountOption returns volume's mount options.
func (*Volume) VolumeContext ¶
func (v *Volume) VolumeContext() VolumeContext
VolumeContext return volume's context.
type VolumeCondition ¶
type VolumeCondition struct {
Type VolumeConditionType `json:"type"`
Status ConditionStatus `json:"status"`
LastProbeTime *time.Time `json:"lastProbeTime,omitempty"`
LastTransitionTime *time.Time `json:"lastTransitionTime,omitempty"`
Reason string `json:"reason,omitempty"`
Message string `json:"message,omitempty"`
Retry int `json:"retry,omitempty"`
}
VolumeCondition represents volume condition struct.
type VolumeConditionType ¶
type VolumeConditionType string
VolumeConditionType defines volume condition type.
const ( // VolumeScheduledrepresents status of the scheduling process for this Volume. VolumeScheduled VolumeConditionType = "Scheduled" // VolumeInitialized means that all init containers in the Volume have started successfully. VolumeInitialized VolumeConditionType = "Initialized" // VolumeStopped means that all init containers in the Volume have stopped successfully. VolumeStopped VolumeConditionType = "Stopped" // VolumeStarted means that all init containers in the Volume have started successfully. VolumeStarted VolumeConditionType = "Started" // VolumeRestarted means that all init containers in the Volume have restarted successfully VolumeRestarted VolumeConditionType = "Restarted" // VolumeUpdated means that all init containers in the Volume have updated successfully VolumeUpdated VolumeConditionType = "Updated" // VolumeDeleted means that all init containers in the Volume have deleted successfully VolumeDeleted VolumeConditionType = "Deleted" )
These are valid conditions of pod.
type VolumeConfig ¶
type VolumeConfig struct {
Size string `json:"size"`
FileSystem string `json:"filesystem"`
MountOpt string `json:"mountopt"`
WriteBPS int64 `json:"wbps"`
ReadBPS int64 `json:"rbps"`
WriteIOPS int64 `json:"wiops"`
ReadIOPS int64 `json:"riops"`
TotalIOPS int64 `json:"iops"`
}
VolumeConfig represents volume config.
type VolumeContext ¶
type VolumeContext struct {
Name string
Driver string
Options map[string]string
Labels map[string]string
}
VolumeContext use to define the volume's identity.
func NewVolumeContext ¶
func NewVolumeContext(name, driver string, options, labels map[string]string) VolumeContext
NewVolumeContext returns VolumeContext instance.
func (VolumeContext) Equal ¶
func (v VolumeContext) Equal(v1 VolumeContext) bool
Equal check VolumeContext is equal or not.
func (VolumeContext) Invalid ¶
func (v VolumeContext) Invalid() bool
Invalid is used to check VolumeContext's name is valid or not.
func (VolumeContext) String ¶
func (v VolumeContext) String() string
String return VolumeContext with string.
type VolumePhase ¶
type VolumePhase string
VolumePhase defines volume phase's status.
var ( // VolumePhasePending represents volume pending status. VolumePhasePending VolumePhase = "Pending" // VolumePhaseReady represents volume ready status. VolumePhaseReady VolumePhase = "Ready" // VolumePhaseUnknown represents volume unknown status. VolumePhaseUnknown VolumePhase = "Unknown" // VolumePhaseFailed represents volume failed status. VolumePhaseFailed VolumePhase = "Failed" )
type VolumeSpec ¶
type VolumeSpec struct {
ClusterID string `json:"clusterid"`
Operable bool `json:"operable"`
Backend string `json:"backend,omitempty"`
MountMode string `json:"mountMode,omitempty"`
*VolumeConfig `json:"config,inline"`
Extra map[string]string `json:"extra"`
}
VolumeSpec represents volume spec.
type VolumeStatus ¶
type VolumeStatus struct {
Phase VolumePhase `json:"phase"`
StartTimestamp *time.Time `json:"startTimestamp"`
LastUpdateTimestamp *time.Time `json:"lastUpdateTime"`
Conditions []VolumeCondition `json:"Conditions,omitempty"`
HostIP string `json:"hostip,omitempty"`
MountPoint string `json:"mountpath,omitempty"`
Reason string `json:"reason"`
Message string `json:"message"`
}
VolumeStatus represent volume status.